\setcounter{errorcontextlines}{100}
\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{vl-report}
    [2018/07/17 v0.1h Dokumentenklasse (RN)]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrreprt}}
\ProcessOptions\relax

\input{glyphtounicode.tex}

\edef\@classoptionslist{ngerman,toc=bibliography,\@classoptionslist}
% "ngerman" als Standard, "toc=bibliography" soll auch "biblatex" sehen.

\PassOptionsToPackage{hyphens}{url}
\PassOptionsToPackage{twoside,headinclude,headlines=1.25}{typearea}
\PassOptionsToClass{
,fontsize=11pt
,paper=a4
,pagesize
,headings=normal
,titlepage=false
}{scrartcl}

\LoadClassWithOptions{scrartcl}

\RequirePackage{hyphsubst}% Trennregeln austauschen
\HyphSubstIfExists{ngerman-x-latest}{%
  \HyphSubstLet{ngerman}{ngerman-x-latest}}{}

% Markus Kohm in "d.c.t.t." (16 Jul 2007 10:15:02 CEST):
%\BeforePackage{babel}{\DeclareOption{fallbacklanguage}{%
%  \ifx\bbl@main@language\@undefined\ExecuteOptions{ngerman}\fi}%
%}%

\RequirePackage{babel}

\RequirePackage{xcolor,scrpage2}
\pagestyle{scrheadings}
\automark[subsection]{section}

%\expandafter\ifnum \@nameuse{scr@v@3.12}=\scr@v@last\relax
%  % wegen Macke in KOMA-Script 3.12 %
%  \RequirePackage{xpatch}
%  \xpatchcmd{\ps@headings}{\sectionmarkformat\fi}{\sectionmarkformat}{}{}
%\fi

\newcommand*\moveTypeArea{%
  \addtolength{\oddsidemargin}{1.75cm}%
  \addtolength{\evensidemargin}{-1.75cm}%
}

\RequirePackage[section]{placeins}% \FloatBarrier{}

\RequirePackage{graphicx}
\RequirePackage[T1]{fontenc}
\RequirePackage[largesmallcaps]{kpfonts}
\RequirePackage[scale=.9]{tgheros}
\iffalse
\RequirePackage[scaled]{luximono}
\else
\RequirePackage[ttdefault=true,scale=1.034]{AnonymousPro}
\fi
\RequirePackage{microtype}
\DeclareMicrotypeAlias{jkp}{ppl}
\DeclareMicrotypeAlias{jkpk}{ppl}

\RequirePackage[obeyspaces,spaces]{url}
\renewcommand\UrlFont{\ttfamily\small}

\RequirePackage[utf8]{inputenc}
\RequirePackage[autostyle=true,babel=once,german=guillemets,maxlevel=3]{csquotes}%
\defineshorthand{"`}{\openautoquote}
\defineshorthand{"'}{\closeautoquote}
\MakeAutoQuote{»}{«}

\addtokomafont{caption}{\small}
\addtokomafont{captionlabel}{\bfseries\sffamily}
\addtokomafont{subject}{\sffamily}

\renewcommand*\labelitemii{$\circ$}

\newcommand\Minisec[1]{\@afterindentfalse \vskip 1.5ex
  {\parindent \z@
    \raggedsection\normalfont\sectfont\nobreak
    \usekomafont{minisec}#1\nobreak}\nobreak%
  \@afterheading
}

\newcommand*\Program[1]{\textsf{#1}}
\newcommand\TODO[1]{%
  \begingroup
    \color{red}\textbf{\textsf{TODO:}} #1%
  \endgroup
}

\RequirePackage{xcolor,listings}
\lstset{%
,basicstyle=\footnotesize\ttfamily
,identifierstyle={}
,keywordstyle=\bfseries
,%stringstyle=\itshape\color{DTKlstStrings}
,commentstyle=\itshape
,columns=fixed
,tabsize=2
,frame=single
,extendedchars=true
,showspaces=false
,showstringspaces=false
,breaklines=true
,breakindent=10pt
,backgroundcolor=\color{black!10}
,breakautoindent=true
,captionpos=t
,aboveskip=\medskipamount
,belowskip=\medskipamount
,xrightmargin=\fboxsep
,prebreak=\mbox{$\hookleftarrow$}
,columns=fullflexible
,keepspaces=true
}

\setlength\textheight{1.08\textheight}

\RequirePackage[
,style=numeric
,language=auto
,hyperref=auto
,abbreviate=true
%,sorting=nyt
,bibencoding=utf8
,block=ragged
,backend=biber
,useprefix=true
,backrefstyle=two
,sortlocale=de_DE
,dateabbrev=false
,datezeros=false
,maxnames=3
,minnames=3
,defernumbers=true
]{biblatex}
\RequirePackage{ragged2e}
\appto{\bibsetup}{\RaggedRight}

\setcounter{biburlnumpenalty}{700}
\setcounter{biburlucpenalty}{700}
\setcounter{biburllcpenalty}{800}

\renewcaptionname{ngerman}\bibname{Literatur und Verweise}
\renewcaptionname{ngerman}\refname{\bibname}
\renewcaptionname{ngerman}\figurename{Abb.}
\DefineBibliographyStrings{ngerman}{%
  bibliography     = {\bibname},
  references       = {\bibname},
}

\renewcommand{\floatpagefraction}{.9}
\renewcommand{\textfraction}{.1}
\renewcommand{\topfraction}{.9}
\renewcommand{\bottomfraction}{.9}
\setcounter{topnumber}{3}
\setcounter{bottomnumber}{3}
\setcounter{totalnumber}{5}
\renewcommand{\dbltopfraction}{.8}
\renewcommand{\dblfloatpagefraction}{.6}

% Einzelne Abbildungen nicht auf leerer Seite zentrieren.
\expandafter\setlength\csname @fptop\endcsname{0pt}

\emergencystretch=3em %
\hfuzz=2pt % --> \overfullrule

%\RequirePackage{titlepage}
%\TitlePageStyle[Optionen]{TU-Dresden}

\renewcommand*\next@tdpage{% mieser Hack; besser machen!
  \null\vskip -1.5cm %
}

\AtBeginDocument{%
  \@ifpackageloaded{hyperref}{%
    \RequirePackage{bookmark}%
  }{}%
}

\RequirePackage{shortvrb}
\MakeShortVerb{\|}

\RequirePackage[neverdecrease]{paralist}
\newcommand*\vl@begin@list[1]{%
  \@ovxx=\parindent
  \@ovyy=\parskip
  \@nameuse{#1}%
  \parindent=\@ovxx
  \parskip=\@ovyy
}
\def\enumerate{%
  \vl@begin@list{compactenum}%
}
\def\itemize{%
  \vl@begin@list{compactitem}%
}
\def\description{%
  \vl@begin@list{compactdesc}%
}
\let\enditemize\endcompactitem
\let\endenumerate\endcompactenum
\let\enddescription\endcompactdesc
\pltopsep=\medskipamount
\plitemsep=\medskipamount

\renewenvironment{titlepage}{%
  \cleardoublepage
  \if@twocolumn
    \@restonecoltrue\onecolumn
  \else
    \@restonecolfalse\newpage
  \fi
  \thispagestyle{empty}%
  \if@compatibility \setcounter{page}{0}\fi
  \addmargin[\dimexpr-\oddsidemargin-1in]{\dimexpr-\evensidemargin-1in}%
    \vspace*{\dimexpr-\topmargin-1in-\headheight-\headsep-\topskip}
    \enlargethispage{\dimexpr\paperheight-\topmargin-\headheight
      -\headsep-\textheight-\footskip-2\baselineskip}%
}{%
  \endaddmargin
  \if@restonecol\twocolumn \else \newpage \fi
}%

\RequirePackage[hyperindex,breaklinks]{hyperref}
%\RequirePackage{breakurl}

\endinput

%%
%% End of file `vl-report.cls'.



